import { __assign } from "tslib";
import React, { useMemo } from 'react';
import { Button, Col, InputGroup, Row } from 'react-bootstrap';
import { Download, Grid3x2Gap, Grid3x3Gap } from 'react-bootstrap-icons';
import { ExportToCsv } from 'export-to-csv-fix-source-map';
import { RBTSearch } from '../search';
/**
 * This component builds a menu bar, this includes the Search box, spacing and download table as a csv.
 *
 * @param {RBTMenuBarOptions} props
 */
export var RBTMenuBar = function (props) {
    var displayCompactBtn = useMemo(function () { var _a; return (_a = props.enableDensityToggle) !== null && _a !== void 0 ? _a : true; }, [props.enableDensityToggle]);
    var displayExportBtn = useMemo(function () { var _a; return (_a = props.enableExportButton) !== null && _a !== void 0 ? _a : true; }, [props.enableExportButton]);
    var styleVarient = useMemo(function () { var _a; return (_a = props.varient) !== null && _a !== void 0 ? _a : 'dark'; }, [props.varient]);
    var tableName = useMemo(function () {
        var result = 'SearchBar';
        if (props.name) {
            if (props.name.length > 0) {
                result = props.name + ' ' + result;
            }
        }
        return result;
    }, [props.name]);
    /**
     * Called by the download button, this will capture the information in the table and
     * return is a CSV for download by the user.
     */
    var performExport = function () {
        var data = props.data.map(function (value) { return value.data; });
        var exportName = 'Unknown' + '_' + Date.now();
        if (props.name) {
            if (props.name.length > 0) {
                exportName = props.name + '_' + Date.now();
            }
        }
        // Define rules for exporting.
        var csvExport = new ExportToCsv({
            showLabels: true,
            filename: exportName,
            useKeysAsHeaders: true,
        });
        csvExport.generateCsv(data);
    };
    return (React.createElement(React.Fragment, null, displayCompactBtn || displayExportBtn ? (React.createElement(Row, null,
        React.createElement(Col, null),
        React.createElement(Col, { md: 'auto' },
            React.createElement(InputGroup, null,
                React.createElement(RBTSearch, __assign({}, props)),
                displayCompactBtn ? (React.createElement(Button, { variant: styleVarient, "aria-label": tableName + ' Compact Setting Toggle', onClick: function () {
                        if (props.setCompact) {
                            props.setCompact(!props.isCompact);
                        }
                    } }, props.isCompact ? React.createElement(Grid3x3Gap, null) : React.createElement(Grid3x2Gap, null))) : null,
                displayExportBtn ? (React.createElement(Button, { variant: styleVarient, "aria-label": tableName + ' Download CSV Button', tabIndex: 0, onClick: function () { return performExport(); } },
                    React.createElement(Download, null))) : null)))) : null));
};
//# sourceMappingURL=menubar.components.js.map