import React, { useCallback, useMemo } from 'react';
import { Form, InputGroup } from 'react-bootstrap';
import { Search } from 'react-bootstrap-icons';
import { updateFilterAndDisplayed } from './search.helpers';
/**
 * This is used to provide a search bar which will look through the supplied data objects and mark them as
 * filtered/not filtered dependning on search criteria provided.
 *
 * @component
 * @param {RBTSearchOptions} param0 this is used
 */
export var RBTSearch = function (_a) {
    var columns = _a.columns, data = _a.data, name = _a.name, handleDisplayedRows = _a.handleDisplayedRows;
    var tableName = useMemo(function () {
        var result = 'Search Bar';
        if (name) {
            if (name.length > 0) {
                result = name + ' ' + result;
            }
        }
        return result;
    }, [name]);
    /**
     * Columns must be marked as searchable, for the search bar to include them in analysis.
     */
    var searchableColumns = useMemo(function () {
        var keys = [];
        columns === null || columns === void 0 ? void 0 : columns.forEach(function (value) {
            if (value.searchable && value.accessorKey) {
                keys.push(value.accessorKey.toString());
            }
        });
        return keys;
    }, [columns]);
    /**
     * If there are any columns which are searchable, this will be set to true.
     * This value is used to decide if the search bar should be shown.
     */
    var isSearchableTable = useMemo(function () {
        return searchableColumns && searchableColumns.length > 0 && typeof handleDisplayedRows !== 'undefined';
    }, [searchableColumns, handleDisplayedRows]);
    /**
     * This function will iterate over the data with the current search value looking for matches.
     * It will then set the displayed rows callback with the matching results.
     * @param {string} toFind the value to search the stored data for.
     */
    var handleSearchValue = useCallback(function (toFind) {
        if (handleDisplayedRows) {
            // Convert to Upper case to remove case specific issues
            var upperToFind = toFind.toUpperCase();
            var results = updateFilterAndDisplayed(upperToFind, data, searchableColumns);
            handleDisplayedRows(results);
        }
    }, [columns, data]);
    return (React.createElement(React.Fragment, null, isSearchableTable ? (React.createElement(React.Fragment, null,
        React.createElement(Form.Control, { placeholder: 'Search', "aria-label": tableName + ' Search Input', tabIndex: 0, onChange: function (e) { return handleSearchValue(e.target.value); } }),
        React.createElement(InputGroup.Text, null,
            React.createElement(Search, null)))) : null));
};
//# sourceMappingURL=search.components.js.map