import { RemoveFilterFromArray } from '../common';
/** Unique value for filters applied by this component. */
export var FILTER_VALUE = 'search';
export var updateFilterAndDisplayed = function (toFind, rows, searchableColumns) {
    var results = [];
    //iterate over each table record to find ones which match our search term
    rows === null || rows === void 0 ? void 0 : rows.forEach(function (row) {
        // If the filtering status of the row has changed we need to capture this and feed
        // it back to the other components.
        if (isMatch(toFind, row, searchableColumns)) {
            row.filters = RemoveFilterFromArray(FILTER_VALUE, row.filters);
        }
        else if (row.filters.indexOf(FILTER_VALUE) < 0) {
            row.filters.push(FILTER_VALUE);
        }
        results.push(row);
    });
    // if we haven't changed what is displayed update nothing!
    return results;
};
/**
 * Supplies a value and a table row. This will check the defined fields within the table to
 * see if they match the value. If they do it will return true.
 *
 * @param toFind the term to find within the data
 * @param row the row containing the data object we need to check
 * @param searchableColumns the fields in the data object we should compare
 * @returns true if toFind is empty
 */
export var isMatch = function (toFind, row, searchableColumns) {
    // if toFind is cleared then we assume nothing is filtered.
    var match = toFind.length == 0;
    var data = row.data;
    if (data) {
        var toFindUpper_1 = toFind.toUpperCase();
        searchableColumns.forEach(function (key) {
            // TODO This needs to be configured for multi level objects
            var value = data[key];
            if (typeof value === 'string') {
                match = match || value.toUpperCase().indexOf(toFindUpper_1) > -1;
            }
        });
    }
    return match;
};
//# sourceMappingURL=search.helpers.js.map