import React, { useMemo } from 'react';
/**
 * Generates a thead for the React Bootstrap Table, this might return an empty thead if
 * @param {RBTableHeadOptions} param0
 * @returns {ReactNode} the <thead> element for our React Bootstrap Table, populated based on the contents of the columns parameter.
 */
export var RBTableHead = function (_a) {
    var columns = _a.columns, enableTableHead = _a.enableTableHead, name = _a.name, varient = _a.varient;
    var styleVarient = useMemo(function () { return varient !== null && varient !== void 0 ? varient : 'dark'; }, [varient]);
    var columnPrefix = useMemo(function () { return (name && name.length > 0 ? name + '.table.head' : 'table.head'); }, [name]);
    /**
     * Used to either reach out to a Header Function to define the contents of a Table Header Column, or return the header name.
     * @param {RBTColumnDefs} column the column we are generates a th element for.
     * @returns ReactNode a table head element container either the Header text or the contents of a function call.
     */
    var GenerateHeader = function (column) {
        var id = columnPrefix;
        if (column.id && column.id.length > 0) {
            id = column.id;
        }
        else if (column.header && column.header.length > 0) {
            id = columnPrefix + column.header.replace(' ', '');
        }
        var headerText = id;
        if (column.header && column.header.length > 0) {
            headerText = column.header;
        }
        var result = undefined;
        if (column.id) {
            if (typeof column.Header === 'function') {
                result = (React.createElement("th", { key: id, "aria-label": id }, column.Header({ id: id, header: headerText })));
            }
            else {
            }
        }
        // If there was no Id or Cell then result should be undefined
        if (!result && column.header) {
            var data = column.header;
            if (typeof data === 'string' || typeof data === 'number') {
                result = (React.createElement("th", { key: id, "aria-label": id }, data));
            }
            else {
                console.log('GenerateHeader - Unable to convert data into table header: ' + JSON.stringify(data));
                result = React.createElement("th", { key: id, "aria-label": id });
            }
        }
        return result;
    };
    return (React.createElement("thead", { className: 'table-' + styleVarient },
        React.createElement("tr", { "aria-label": columnPrefix }, enableTableHead ? columns === null || columns === void 0 ? void 0 : columns.map(function (column) { return GenerateHeader(column); }) : null)));
};
//# sourceMappingURL=tableHead.components.js.map